@@ -11,6 +11,7 @@
 #define ERR_ADJ_LIST      "unable to create adjacency list"
 #define ERR_ISECT_LIST    "unable to create intersection list"
 #define ERR_INVALID_BASIS "invalid basis"
+#define ERR_INFER_BASIS   "cannot infer basis"
 #define ERR_ENT_TYPE      "invalid entity type"
 #define ERR_ARR_TYPE      "invalid element type"
 #define ERR_ARR_INSTANCE  "members of array must have same base instance"
@@ -21,5 +22,9 @@
 #define ERR_GEOM_SET_CTOR "cannot take instance and iGeom.EntitySet"
 #define ERR_GEOM_TAG_CTOR "cannot take instance and iGeom.Tag"
 #define ERR_UNKNOWN_INST  "unknown iBase instance"
+#define ERR_NO_SRC_DST    "must supply src and/or dest"
+#define ERR_INVALID_STG   "invalid storage order"
+#define ERR_INVALID_TYPE  "invalid type"
+#define ERR_INVALID_TOPO  "invalid topology"
 
 #endif
