@@ -1,6 +1,7 @@
 #define _IBASE_MODULE
 #include "iBase_Python.h"
 #include "common.h"
+#include "errors.h"
 
 #include <numpy/arrayobject.h>
 #include <numpy/ufuncobject.h>
@@ -102,6 +103,67 @@ ArrDealloc_New(PyObject *base, void *memory)
     return o;
 }
 
+static int
+iBaseType_Cvt(PyObject *object,int *val)
+{
+    int tmp = PyInt_AsLong(object);
+    if(PyErr_Occurred())
+        return 0;
+    if(tmp < iBase_VERTEX || tmp > iBase_ALL_TYPES)
+    {
+        PyErr_SetString(PyExc_ValueError,ERR_INVALID_TYPE);
+        return 0;
+    }
+
+    *val = tmp;
+    return 1;
+}
+
+static int
+iBaseStorageOrder_Cvt(PyObject *object,int *val)
+{
+    int tmp = PyInt_AsLong(object);
+    if(PyErr_Occurred())
+        return 0;
+    if(tmp < iBase_BLOCKED || tmp > iBase_INTERLEAVED)
+    {
+        PyErr_SetString(PyExc_ValueError,ERR_INVALID_STG);
+        return 0;
+    }
+
+    *val = tmp;
+    return 1;
+}
+
+static char typechars[] = {'i','d','E','b'};
+
+static int
+iBaseTagType_Cvt(PyObject *object,int *val)
+{
+    int i;
+    char c;
+    if( !PyArg_Parse(object,"c",&c))
+        return 0;
+
+    for(i=0; i<sizeof(typechars); i++)
+    {
+        if(typechars[i] == c)
+        {
+            *val = i;
+            return 1;
+        }
+    }
+
+    PyErr_SetString(PyExc_ValueError,ERR_TYPE_CODE);
+    return 0;
+}
+
+static char
+iBaseTagType_ToChar(enum iBase_TagValueType t)
+{
+    return typechars[t];
+}
+
 PyMODINIT_FUNC initiBase(void)
 {
     PyArray_Descr *descr;
@@ -132,6 +194,10 @@ PyMODINIT_FUNC initiBase(void)
         &iBaseEntityArr_equal,
         &iBaseEntitySetArr_equal,
         &iBaseTagArr_equal,
+        &iBaseType_Cvt,
+        &iBaseStorageOrder_Cvt,
+        &iBaseTagType_Cvt,
+        &iBaseTagType_ToChar,
     };
     IBase_API[0] = PyExc_ITAPSError;
     PyObject *api_obj;
