@@ -10,6 +10,8 @@ extern "C" {
 #endif
 
 typedef void (*equal_ufunc)(char **,npy_intp *,npy_intp *,void *);
+typedef int (*cvtfunc)(PyObject *,int *);
+typedef char (*typetochfunc)(enum iBase_TagValueType t);
 
 typedef struct
 {
@@ -110,6 +112,10 @@ static void **IBase_API = NULL;
 #define iBaseEntityArr_equal    ( (equal_ufunc)  IBase_API[10])
 #define iBaseEntitySetArr_equal ( (equal_ufunc)  IBase_API[11])
 #define iBaseTagArr_equal       ( (equal_ufunc)  IBase_API[12])
+#define iBaseType_Cvt           ( (cvtfunc)      IBase_API[13])
+#define iBaseStorageOrder_Cvt   ( (cvtfunc)      IBase_API[14])
+#define iBaseTagType_Cvt        ( (cvtfunc)      IBase_API[15])
+#define iBaseTagType_ToChar     ( (typetochfunc) IBase_API[16])
 
 
 #if !defined(NO_IMPORT_IBASE) && !defined(NO_IMPORT)
