@@ -63,8 +63,8 @@ typedef struct
 enum iGeomExt_Basis
 {
     iGeomExt_XYZ,
-    iGeomExt_U,
-    iGeomExt_UV
+    iGeomExt_UV,
+    iGeomExt_U
 };
 
 
@@ -99,6 +99,7 @@ static void **IGeom_API = NULL;
 #define Deriv2nd_Type       (*(PyTypeObject*)    IGeom_API[12])
 #define Intersect_Type      (*(PyTypeObject*)    IGeom_API[13])
 #define Tolerance_Type      (*(PyTypeObject*)    IGeom_API[14])
+#define iGeomBasis_Cvt      ( (cvtfunc)          IGeom_API[15])
 
 
 #if !defined(NO_IMPORT_IGEOM) && !defined(NO_IMPORT)
