@@ -8,9 +8,7 @@
 #include <numpy/ufuncobject.h>
 
 static PyObject *CreateEnt_Type;
-
-static enum iBase_TagValueType char_to_type(char c);
-static char type_to_char(enum iBase_TagValueType t);
+static PyObject *AdjEntIndices_Type;
 
 static PyTypeObject iMesh_Type;
 static PyTypeObject iMeshIter_Type;
@@ -37,6 +35,22 @@ checkError(iMesh_Instance mesh,int err)
         return 0;
 }
 
+static int
+iMeshTopology_Cvt(PyObject *object,int *val)
+{
+    int tmp = PyInt_AsLong(object);
+    if(PyErr_Occurred())
+        return 0;
+    if(tmp < iMesh_POINT || tmp > iMesh_ALL_TOPOLOGIES)
+    {
+        PyErr_SetString(PyExc_ValueError,ERR_INVALID_TOPO);
+        return 0;
+    }
+
+    *val = tmp;
+    return 1;
+}
+
 static iMeshEntitySet_Object *
 iMeshEntitySet_New(iMesh_Object *instance)
 {
@@ -169,15 +183,16 @@ static PyObject *
 iMeshObj_areEHValid(iMesh_Object *self,PyObject *args,PyObject *kw)
 {
     static char *kwlist[] = {"reset",0};
-    int reset,invariant,err;
-    if(!PyArg_ParseTupleAndKeywords(args,kw,"i",kwlist,&reset))
+    PyObject *reset;
+    int invariant,err;
+    if(!PyArg_ParseTupleAndKeywords(args,kw,"O!",kwlist,&PyBool_Type,&reset))
         return NULL;
 
-    iMesh_areEHValid(self->handle,reset,&invariant,&err);
+    iMesh_areEHValid(self->handle,(reset==Py_True),&invariant,&err);
     if(checkError(self->handle,err))
         return NULL;
 
-    return PyInt_FromLong(invariant);
+    return PyBool_FromLong(invariant);
 }
 
 static PyObject *
@@ -185,22 +200,16 @@ iMeshObj_getVtxCoords(iMesh_Object *self,PyObject *args,PyObject *kw)
 {
     static char *kwlist[] = {"entities","storage_order",0};
     PyObject *obj;
-    int storage_order=-1;
+    int storage_order = iBase_INTERLEAVED;
     int err;
 
-    if(!PyArg_ParseTupleAndKeywords(args,kw,"O|i",kwlist,&obj,&storage_order))
+    if(!PyArg_ParseTupleAndKeywords(args,kw,"O|O&",kwlist,&obj,
+                                    iBaseStorageOrder_Cvt,&storage_order))
         return NULL;
 
     PyObject *ents = PyArray_TryFromObject(obj,NPY_IBASEENT,1,1);
     if(ents)
     {
-        if(storage_order == -1)
-        {
-            Py_DECREF(ents);
-            PyErr_SetString(PyExc_ValueError,ERR_STORAGE_ORDER);
-            return NULL;
-        }
-
         int size;
         double *coords=0;
         int coords_alloc=0,coords_size;
@@ -346,7 +355,8 @@ iMeshObj_getEntAdj(iMesh_Object *self,PyObject *args,PyObject *kw)
     int type_req;
     int err;
 
-    if(!PyArg_ParseTupleAndKeywords(args,kw,"Oi",kwlist,&obj,&type_req))
+    if(!PyArg_ParseTupleAndKeywords(args,kw,"OO&",kwlist,&obj,iBaseType_Cvt,
+                                    &type_req))
         return NULL;
 
     PyObject *ents = PyArray_TryFromObject(obj,NPY_IBASEENT,1,1);
@@ -407,8 +417,8 @@ iMeshObj_getEnt2ndAdj(iMesh_Object *self,PyObject *args,PyObject *kw)
     int bridge_type,type_req;
     int err;
 
-    if(!PyArg_ParseTupleAndKeywords(args,kw,"Oii",kwlist,&obj,&bridge_type,
-                                    &type_req))
+    if(!PyArg_ParseTupleAndKeywords(args,kw,"OO&O&",kwlist,&obj,iBaseType_Cvt,
+                                    &bridge_type,iBaseType_Cvt,&type_req))
         return NULL;
 
     PyObject *ents = PyArray_TryFromObject(obj,NPY_IBASEENT,1,1);
@@ -464,18 +474,15 @@ static PyObject *
 iMeshObj_createEntSet(iMesh_Object *self,PyObject *args,PyObject *kw)
 {
     static char *kwlist[] = {"ordered",0};
-    int isList,err;
-    PyObject *obj;
+    int err;
+    PyObject *ordered;
     iMeshEntitySet_Object *set;
 
-    if(!PyArg_ParseTupleAndKeywords(args,kw,"O!",kwlist,&PyBool_Type,&obj))
+    if(!PyArg_ParseTupleAndKeywords(args,kw,"O!",kwlist,&PyBool_Type,&ordered))
         return NULL;
 
     set = iMeshEntitySet_New(self);
-
-    isList = (obj == Py_True);
-  
-    iMesh_createEntSet(self->handle,isList,&set->base.handle,&err);
+    iMesh_createEntSet(self->handle,(ordered==Py_True),&set->base.handle,&err);
     if(checkError(self->handle,err))
     {
         Py_DECREF((PyObject*)set);
@@ -508,26 +515,19 @@ iMeshObj_setVtxCoords(iMesh_Object *self,PyObject *args,PyObject *kw)
 {
     static char *kwlist[] = {"entities","coords","storage_order",0};
     PyObject *obj;
-    int storage_order = -1;
+    int storage_order = iBase_INTERLEAVED;
     PyObject *data;
     PyObject *ents = 0;
     PyObject *verts = 0;
     int err;
 
-    if(!PyArg_ParseTupleAndKeywords(args,kw,"OO|i",kwlist,&obj,&data,
-                                    &storage_order))
+    if(!PyArg_ParseTupleAndKeywords(args,kw,"OO|O&",kwlist,&obj,&data,
+                                    iBaseStorageOrder_Cvt,&storage_order))
         return NULL;
 
     ents = PyArray_TryFromObject(obj,NPY_IBASEENT,1,1);
     if(ents)
     {
-        if(storage_order == -1)
-        {
-            Py_DECREF(ents);
-            PyErr_SetString(PyExc_ValueError,ERR_STORAGE_ORDER);
-            goto err;
-        }
-
         verts = PyArray_ToVectors(data,NPY_DOUBLE,2,3,
                                   storage_order==iBase_INTERLEAVED);
         if(verts == NULL)
@@ -575,23 +575,17 @@ static PyObject *
 iMeshObj_createVtx(iMesh_Object *self,PyObject *args,PyObject *kw)
 {
     static char *kwlist[] = {"coords","storage_order",0};
-    int storage_order=-1;
+    int storage_order = iBase_INTERLEAVED;
     PyObject *data;
     PyObject *vertices;
     int err;
 
-    if(!PyArg_ParseTupleAndKeywords(args,kw,"O|i",kwlist,&data,&storage_order))
+    if(!PyArg_ParseTupleAndKeywords(args,kw,"O|O&",kwlist,&data,
+                                    iBaseStorageOrder_Cvt,&storage_order))
         return NULL;
 
     if( (vertices = PyArray_TryFromObject(data,NPY_DOUBLE,2,2)) != NULL)
     {
-        if(storage_order == -1)
-        {
-            Py_DECREF(vertices);
-            PyErr_SetString(PyExc_ValueError,ERR_STORAGE_ORDER);
-            return NULL;
-        }
-
         int index = storage_order == iBase_BLOCKED;
         int count = PyArray_DIM(vertices,index); /* this is a bit odd! */
         int coord_size = PyArray_SIZE(vertices);
@@ -644,7 +638,8 @@ iMeshObj_createEnt(iMesh_Object *self,PyObject *args,PyObject *kw)
     int topo,status,err;
     PyObject *obj;
 
-    if(!PyArg_ParseTupleAndKeywords(args,kw,"iO",kwlist,&topo,&obj))
+    if(!PyArg_ParseTupleAndKeywords(args,kw,"O&O",kwlist,iMeshTopology_Cvt,
+                                    &topo,&obj))
         return NULL;
 
     PyObject *ents = PyArray_FROMANY(obj,NPY_IBASEENT,1,1,NPY_C_CONTIGUOUS);
@@ -675,7 +670,8 @@ iMeshObj_createEntArr(iMesh_Object *self,PyObject *args,PyObject *kw)
     int topo,err;
     PyObject *obj;
 
-    if(!PyArg_ParseTupleAndKeywords(args,kw,"iO",kwlist,&topo,&obj))
+    if(!PyArg_ParseTupleAndKeywords(args,kw,"O&O",kwlist,iMeshTopology_Cvt,
+                                    &topo,&obj))
         return NULL;
 
     PyObject *ents = PyArray_FROMANY(obj,NPY_IBASEENT,1,1,NPY_C_CONTIGUOUS);
@@ -745,22 +741,14 @@ iMeshObj_createTag(iMesh_Object *self,PyObject *args,PyObject *kw)
 {
     static char *kwlist[] = {"name","size","type",0};
     char *name;
-    char typechar;
     int size,type,err;
     iMeshTag_Object *tag;
 
-    if(!PyArg_ParseTupleAndKeywords(args,kw,"sic",kwlist,&name,&size,&typechar))
+    if(!PyArg_ParseTupleAndKeywords(args,kw,"siO&",kwlist,&name,&size,
+                                    iBaseTagType_Cvt,&type))
         return NULL;
 
-    type = char_to_type(typechar);
-    if(type == -1)
-    {
-        PyErr_SetString(PyExc_ValueError,ERR_TYPE_CODE);
-        return NULL;
-    }
-
     tag = iMeshTag_New(self);
-
     iMesh_createTag(self->handle,name,size,type,&tag->base.handle,&err,
                     strlen(name));
     if(checkError(self->handle,err))
@@ -776,17 +764,15 @@ static PyObject *
 iMeshObj_destroyTag(iMesh_Object *self,PyObject *args,PyObject *kw)
 {
     static char *kwlist[] = {"tag","force",0};
-    int forced,err;
+    int err;
     iBaseTag_Object *tag;
-    PyObject *obj;
+    PyObject *forced;
 
     if(!PyArg_ParseTupleAndKeywords(args,kw,"O!O!",kwlist,&iBaseTag_Type,&tag,
-                                    &PyBool_Type,&obj))
+                                    &PyBool_Type,&forced))
         return NULL;
 
-    forced = (obj == Py_True);
-
-    iMesh_destroyTag(self->handle,tag->handle,forced,&err);
+    iMesh_destroyTag(self->handle,tag->handle,(forced==Py_True),&err);
     if(checkError(self->handle,err))
         return NULL;
 
@@ -1148,9 +1134,10 @@ PyMODINIT_FUNC initiMesh(void)
         &iMeshTag_Type,
         &NPY_IMESHENTSET,
         &NPY_IMESHTAG,
-        iMeshEntitySet_New,
-        iMeshTag_New,
+        &iMeshEntitySet_New,
+        &iMeshTag_New,
         &CreateEnt_Type,
+        &iMeshTopology_Cvt,
     };
     PyObject *api_obj;
 
@@ -1221,8 +1208,8 @@ PyMODINIT_FUNC initiMesh(void)
     PyUFunc_RegisterLoopForType(ufunc,NPY_IMESHTAG,iBaseTagArr_equal,types,0);
 
     /***** create named tuple types *****/
-    /* TODO: add this to the module dictionary and do error checking */
-    CreateEnt_Type = NamedTuple_CreateType("create_ent","entity status");
+    CreateEnt_Type     = NamedTuple_CreateType(m,"create_ent","entity status");
+    AdjEntIndices_Type = NamedTuple_CreateType(m,"adj_ent",   "entities adj");
 }
 
 /* Include source files so that everything is in one translation unit */
