@@ -1,5 +1,4 @@
 from itaps import iBase, iGeom
-from itaps.iBase import StorageOrder as Stg
 import unittest
 import numpy
 
@@ -7,13 +6,10 @@ class TestDiff(unittest.TestCase):
     def setUp(self):
         self.geom = iGeom.Geom()
 
-        # TODO: for some reason this is necessary to make the geometry engine
-        # play nice
-        self.empty = self.geom.createEntSet(True)
-
     def tearDown(self):
         self.geom.deleteAll()
-        self.geom = None
+        # Note: This breaks all but the first-run test when using CGM
+        # self.geom = None
 
     def testClosestPt(self):
         self.geom.createBrick(2, 2, 2)
@@ -28,23 +24,19 @@ class TestDiff(unittest.TestCase):
         ##### 1 entity, 1 vertex
         coords = self.geom.getEntClosestPt(faces[0], [0,0,0])
         self.assert_((coords == result[0]).all())
-        coords = self.geom.getEntClosestPt(faces[0:1], [0,0,0],
-                                           storage_order=Stg.interleaved)
+        coords = self.geom.getEntClosestPt(faces[0:1], [0,0,0])
         self.assert_((coords == result[0:1]).all())
 
         ##### 1 entity, n vertices
-        coords = self.geom.getEntClosestPt(faces[0], [[0,0,0]]*6,
-                                           storage_order=Stg.interleaved)
+        coords = self.geom.getEntClosestPt(faces[0], [[0,0,0]]*6)
         self.assert_((coords == result[0:1]*6).all())
 
         ##### n entities, 1 vertex
-        coords = self.geom.getEntClosestPt(faces, [0,0,0],
-                                           storage_order=Stg.interleaved)
+        coords = self.geom.getEntClosestPt(faces, [0,0,0])
         self.assert_((coords == result).all())
 
         ##### n entities, n vertices
-        coords = self.geom.getEntClosestPt(faces, [[0,0,0]]*6,
-                                           storage_order=Stg.interleaved)
+        coords = self.geom.getEntClosestPt(faces, [[0,0,0]]*6)
         self.assert_((coords == result).all())
 
     def testNormalXYZ(self):
@@ -60,19 +52,19 @@ class TestDiff(unittest.TestCase):
         ##### 1 entity, 1 vertex
         coords = self.geom.getEntNormal(faces[0], [0,0,0])
         self.assert_((coords == result[0]).all())
-        coords = self.geom.getEntNormal(faces[0:1], [0,0,0], Stg.interleaved)
+        coords = self.geom.getEntNormal(faces[0:1], [0,0,0])
         self.assert_((coords == result[0:1]).all())
 
         ##### 1 entity, n vertices
-        coords = self.geom.getEntNormal(faces[0], [[0,0,0]]*6, Stg.interleaved)
+        coords = self.geom.getEntNormal(faces[0], [[0,0,0]]*6)
         self.assert_((coords == result[0:1]*6).all())
 
         ##### n entities, 1 vertex
-        coords = self.geom.getEntNormal(faces, [0,0,0], Stg.interleaved)
+        coords = self.geom.getEntNormal(faces, [0,0,0])
         self.assert_((coords == result).all())
 
         ##### n entities, n vertices
-        coords = self.geom.getEntNormal(faces, [[0,0,0]]*6, Stg.interleaved)
+        coords = self.geom.getEntNormal(faces, [[0,0,0]]*6)
         self.assert_((coords == result).all())
 
     def testNormalUV(self):
@@ -86,25 +78,21 @@ class TestDiff(unittest.TestCase):
                    [ 1,  0,  0] ]
 
         ##### 1 entity, 1 vertex
-        coords = self.geom.getEntNormal(faces[0], [0,0], basis=iGeom.Basis.uv)
+        coords = self.geom.getEntNormal(faces[0], [0,0], iGeom.Basis.uv)
         self.assert_((coords == result[0]).all())
-        coords = self.geom.getEntNormal(faces[0:1], [0,0], Stg.interleaved,
-                                        iGeom.Basis.uv)
+        coords = self.geom.getEntNormal(faces[0:1], [0,0], iGeom.Basis.uv)
         self.assert_((coords == result[0:1]).all())
 
         ##### 1 entity, n vertices
-        coords = self.geom.getEntNormal(faces[0], [[0,0]]*6, Stg.interleaved,
-                                        iGeom.Basis.uv)
+        coords = self.geom.getEntNormal(faces[0], [[0,0]]*6, iGeom.Basis.uv)
         self.assert_((coords == result[0:1]*6).all())
 
         ##### n entities, 1 vertex
-        coords = self.geom.getEntNormal(faces, [0,0], Stg.interleaved,
-                                        iGeom.Basis.uv)
+        coords = self.geom.getEntNormal(faces, [0,0], iGeom.Basis.uv)
         self.assert_((coords == result).all())
 
         ##### n entities, n vertices
-        coords = self.geom.getEntNormal(faces, [[0,0]]*6, Stg.interleaved,
-                                        iGeom.Basis.uv)
+        coords = self.geom.getEntNormal(faces, [[0,0]]*6, iGeom.Basis.uv)
         self.assert_((coords == result).all())
 
     def testNormalPl(self):
@@ -121,25 +109,22 @@ class TestDiff(unittest.TestCase):
         norm, pts = self.geom.getEntNormalPl(faces[0], [0,0,0])
         self.assert_((norm == result[0]).all())
         self.assert_((pts  == result[0]).all())
-        norm, pts = self.geom.getEntNormalPl(faces[0:1], [0,0,0],
-                                             Stg.interleaved)
+        norm, pts = self.geom.getEntNormalPl(faces[0:1], [0,0,0])
         self.assert_((norm == result[0:1]).all())
         self.assert_((pts  == result[0:1]).all())
 
         ##### 1 entity, n vertices
-        norm, pts = self.geom.getEntNormalPl(faces[0], [[0,0,0]]*6,
-                                             Stg.interleaved)
+        norm, pts = self.geom.getEntNormalPl(faces[0], [[0,0,0]]*6)
         self.assert_((norm == result[0:1]*6).all())
         self.assert_((pts  == result[0:1]*6).all())
 
         ##### n entities, 1 vertex
-        norm, pts = self.geom.getEntNormalPl(faces, [0,0,0], Stg.interleaved)
+        norm, pts = self.geom.getEntNormalPl(faces, [0,0,0])
         self.assert_((norm == result).all())
         self.assert_((pts  == result).all())
 
         ##### n entities, n vertices
-        norm, pts = self.geom.getEntNormalPl(faces, [[0,0,0]]*6,
-                                             Stg.interleaved)
+        norm, pts = self.geom.getEntNormalPl(faces, [[0,0,0]]*6)
         self.assert_((norm == result).all())
         self.assert_((pts  == result).all())
 
@@ -162,21 +147,19 @@ class TestDiff(unittest.TestCase):
         ##### 1 entity, 1 vertex
         coords = self.geom.getEntTangent(edges[0], [0,0,0])
         self.assert_((coords == result[0]).all())
-        coords = self.geom.getEntTangent(edges[0:1], [0,0,0], Stg.interleaved)
+        coords = self.geom.getEntTangent(edges[0:1], [0,0,0])
         self.assert_((coords == result[0:1]).all())
 
         ##### 1 entity, n vertices
-        coords = self.geom.getEntTangent(edges[0], [[0,0,0]]*12, 
-                                         Stg.interleaved)
+        coords = self.geom.getEntTangent(edges[0], [[0,0,0]]*12)
         self.assert_((coords == result[0:1]*12).all())
 
         ##### n entities, 1 vertex
-        coords = self.geom.getEntTangent(edges, [0,0,0], Stg.interleaved)
+        coords = self.geom.getEntTangent(edges, [0,0,0])
         self.assert_((coords == result).all())
 
         ##### n entities, n vertices
-        coords = self.geom.getEntTangent(edges, [[0,0,0]]*12,
-                                         Stg.interleaved)
+        coords = self.geom.getEntTangent(edges, [[0,0,0]]*12)
         self.assert_((coords == result).all())
 
     def testTangentU(self):
@@ -196,25 +179,21 @@ class TestDiff(unittest.TestCase):
                    [ 0,  0, -1] ]
 
         ##### 1 entity, 1 vertex
-        coords = self.geom.getEntTangent(edges[0], [0], basis=iGeom.Basis.u)
+        coords = self.geom.getEntTangent(edges[0], [0], iGeom.Basis.u)
         self.assert_((coords == result[0]).all())
-        coords = self.geom.getEntTangent(edges[0:1], [0], Stg.interleaved,
-                                         iGeom.Basis.u)
+        coords = self.geom.getEntTangent(edges[0:1], [0], iGeom.Basis.u)
         self.assert_((coords == result[0:1]).all())
 
         ##### 1 entity, n vertices
-        coords = self.geom.getEntTangent(edges[0], [[0]]*12, Stg.interleaved,
-                                         iGeom.Basis.u)
+        coords = self.geom.getEntTangent(edges[0], [[0]]*12, iGeom.Basis.u)
         self.assert_((coords == result[0:1]*12).all())
 
         ##### n entities, 1 vertex
-        coords = self.geom.getEntTangent(edges, [0], Stg.interleaved,
-                                         iGeom.Basis.u)
+        coords = self.geom.getEntTangent(edges, [0], iGeom.Basis.u)
         self.assert_((coords == result).all())
 
         ##### n entities, n vertices
-        coords = self.geom.getEntTangent(edges, [[0]]*12, Stg.interleaved,
-                                         iGeom.Basis.u)
+        coords = self.geom.getEntTangent(edges, [[0]]*12, iGeom.Basis.u)
         self.assert_((coords == result).all())
 
     def testCurvatureXYZ(self):
@@ -228,21 +207,19 @@ class TestDiff(unittest.TestCase):
         coords = self.geom.getEntCurvature(edges[0], [0,1,0],
                                            type=iBase.Type.edge)
         self.assert_((coords == [0,-1,0]).all())
-        coords = self.geom.getEntCurvature(edges[0:1], [0,1,0], Stg.interleaved)
+        coords = self.geom.getEntCurvature(edges[0:1], [0,1,0])
         self.assert_((coords == [[0,-1,0]]).all())
 
         ##### edges; 1 entity, n vertices
-        coords = self.geom.getEntCurvature(edges[0], [[0,1,0],[0,-1,0]],
-                                           Stg.interleaved)
+        coords = self.geom.getEntCurvature(edges[0], [[0,1,0],[0,-1,0]])
         self.assert_((coords == [[0,-1,0],[0,1,0]]).all())
 
         ##### edges; n entities, 1 vertex
-        coords = self.geom.getEntCurvature(edges, [0,1,0], Stg.interleaved)
+        coords = self.geom.getEntCurvature(edges, [0,1,0])
         self.assert_((coords == [[0,-1,0],[0,-1,0]]).all())
 
         ##### edges; n entities, n vertices
-        coords = self.geom.getEntCurvature(edges, [[0,1,0],[0,-1,0]],
-                                           Stg.interleaved)
+        coords = self.geom.getEntCurvature(edges, [[0,1,0],[0,-1,0]])
         self.assert_((coords == [[0,-1,0],[0,1,0]]).all())
 
         ##### faces; 1 entity, 1 vertex
@@ -255,26 +232,25 @@ class TestDiff(unittest.TestCase):
         self.assertEqual(len(coords), 2)
         self.assert_((coords[0] == [0,0,0]).all())
         self.assert_((coords[1] == [1,0,0]).all())
-        coords = self.geom.getEntCurvature(faces[0:1], [0,1,0], Stg.interleaved)
+        coords = self.geom.getEntCurvature(faces[0:1], [0,1,0])
         self.assertEqual(len(coords), 2)
         self.assert_((coords[0] == [0,0,0]).all())
         self.assert_((coords[1] == [1,0,0]).all())
 
         ##### faces; 1 entity, n vertices
-        coords = self.geom.getEntCurvature(faces[0], [[0,1,0],[0,-1,0]],
-                                           Stg.interleaved)
+        coords = self.geom.getEntCurvature(faces[0], [[0,1,0],[0,-1,0]])
         self.assertEqual(len(coords), 2)
         self.assert_((coords[0] == [[0,0,0], [ 0,0,0]]).all())
         self.assert_((coords[1] == [[1,0,0], [-1,0,0]]).all())
 
         ##### faces; n entities, 1 vertex
-        coords = self.geom.getEntCurvature(faces, [0,1,0], Stg.interleaved)
+        coords = self.geom.getEntCurvature(faces, [0,1,0])
         self.assertEqual(len(coords), 2)
         self.assert_((coords[0] == [[0,0,0], [0,0,0], [0,0,0]]).all())
         self.assert_((coords[1] == [[1,0,0], [0,0,0], [0,0,0]]).all())
 
         ##### faces; n entities, n vertices
-        coords = self.geom.getEntCurvature(faces, [[0,1,0]]*3, Stg.interleaved)
+        coords = self.geom.getEntCurvature(faces, [[0,1,0]]*3)
         self.assertEqual(len(coords), 2)
         self.assert_((coords[0] == [[0,0,0], [0,0,0], [0,0,0]]).all())
         self.assert_((coords[1] == [[1,0,0], [0,0,0], [0,0,0]]).all())
@@ -284,40 +260,35 @@ class TestDiff(unittest.TestCase):
         faces = self.geom.getEntities(iBase.Type.face)
 
         ##### 1 entity, 1 vertex
-        coords = self.geom.getEntCurvature(faces[0], [0,0],
-                                           basis=iGeom.Basis.uv)
+        coords = self.geom.getEntCurvature(faces[0], [0,0], iGeom.Basis.uv)
         self.assertEqual(len(coords), 2)
         self.assert_((coords[0] == [ 0, 0, 0]).all())
         self.assert_((coords[1] == [ 0,-1, 0]).all())
-        coords = self.geom.getEntCurvature(faces[0], [0,0],
-                                           basis=iGeom.Basis.uv,
-                                           type=iBase.Type.face)
+        coords = self.geom.getEntCurvature(faces[0], [0,0], iGeom.Basis.uv,
+                                           iBase.Type.face)
         self.assertEqual(len(coords), 2)
         self.assert_((coords[0] == [ 0, 0, 0]).all())
         self.assert_((coords[1] == [ 0,-1, 0]).all())
-        coords = self.geom.getEntCurvature(faces[0:1], [0,0], Stg.interleaved,
-                                           iGeom.Basis.uv)
+        coords = self.geom.getEntCurvature(faces[0:1], [0,0], iGeom.Basis.uv)
         self.assertEqual(len(coords), 2)
         self.assert_((coords[0] == [ 0, 0, 0]).all())
         self.assert_((coords[1] == [ 0,-1, 0]).all())
 
         ##### 1 entity, n vertices
         coords = self.geom.getEntCurvature(faces[0], [[0,0],[0,0]],
-                                           Stg.interleaved, iGeom.Basis.uv)
+                                           iGeom.Basis.uv)
         self.assertEqual(len(coords), 2)
         self.assert_((coords[0] == [[ 0, 0, 0], [ 0, 0, 0]]).all())
         self.assert_((coords[1] == [[ 0,-1, 0], [ 0,-1, 0]]).all())
 
         ##### n entities, 1 vertex
-        coords = self.geom.getEntCurvature(faces, [0,0], Stg.interleaved,
-                                           iGeom.Basis.uv)
+        coords = self.geom.getEntCurvature(faces, [0,0], iGeom.Basis.uv)
         self.assertEqual(len(coords), 2)
         self.assert_((coords[0] == [[ 0, 0, 0], [ 0, 0, 0], [ 0, 0, 0]]).all())
         self.assert_((coords[1] == [[ 0,-1, 0], [ 0, 0, 0], [ 0, 0, 0]]).all())
 
         ##### n entities, n vertices
-        coords = self.geom.getEntCurvature(faces, [[0,0]]*3, Stg.interleaved,
-                                           iGeom.Basis.uv)
+        coords = self.geom.getEntCurvature(faces, [[0,0]]*3, iGeom.Basis.uv)
         self.assertEqual(len(coords), 2)
         self.assert_((coords[0] == [[ 0, 0, 0], [ 0, 0, 0], [ 0, 0, 0]]).all())
         self.assert_((coords[1] == [[ 0,-1, 0], [ 0, 0, 0], [ 0, 0, 0]]).all())
@@ -333,33 +304,30 @@ class TestDiff(unittest.TestCase):
                                [  0, -1,  0] ])
         coords = self.geom.getEntEval(edges[0], [0,1,0])
         self.assert_((coords == result).all())
-        coords = self.geom.getEntEval(edges[0:1], [0,1,0], Stg.interleaved)
+        coords = self.geom.getEntEval(edges[0:1], [0,1,0])
         self.assert_((coords == result.reshape(3,1,3)).all())
-        coords = self.geom.getEntEval(edges[0], [0,1,0], type=iBase.Type.edge)
+        coords = self.geom.getEntEval(edges[0], [0,1,0], iBase.Type.edge)
         self.assert_((coords == result).all())
-        coords = self.geom.getEntEval(edges[0:1], [0,1,0], Stg.interleaved,
-                                      iBase.Type.edge)
+        coords = self.geom.getEntEval(edges[0:1], [0,1,0], iBase.Type.edge)
         self.assert_((coords == result.reshape(3,1,3)).all())
 
         ##### edges; 1 entity, n vertices
         result = numpy.array([ [[  0,  1, -1], [  0, -1, -1]],
                                [[  1,  0,  0], [ -1,  0,  0]],
                                [[  0, -1,  0], [  0,  1,  0]] ])
-        coords = self.geom.getEntEval(edges[0], [[0,1,0], [0,-1,0]],
-                                      Stg.interleaved)
+        coords = self.geom.getEntEval(edges[0], [[0,1,0], [0,-1,0]])
         self.assert_((coords == result).all())
         coords = self.geom.getEntEval(edges[0], [[0,1,0], [0,-1,0]],
-                                      Stg.interleaved, iBase.Type.edge)
+                                      iBase.Type.edge)
         self.assert_((coords == result).all())
 
         ##### edges; n entities, 1 vertex
         result = numpy.array([ [[  0,  1, -1], [  0,  1,  1]],
                                [[  1,  0,  0], [ -1,  0,  0]],
                                [[  0, -1,  0], [  0, -1,  0]] ])
-        coords = self.geom.getEntEval(edges, [0,1,0], Stg.interleaved)
+        coords = self.geom.getEntEval(edges, [0,1,0])
         self.assert_((coords == result).all())
-        coords = self.geom.getEntEval(edges, [0,1,0], Stg.interleaved,
-                                      iBase.Type.edge)
+        coords = self.geom.getEntEval(edges, [0,1,0], iBase.Type.edge)
         self.assert_((coords == result).all())
 
         ##### edges; n entities, n vertices
@@ -367,10 +335,10 @@ class TestDiff(unittest.TestCase):
                                [[  1,  0,  0], [  1,  0,  0]],
                                [[  0, -1,  0], [  0,  1,  0]] ])
         coords = self.geom.getEntEval(edges, [[0,1,0],[0,-1,0]],
-                                      Stg.interleaved, iBase.Type.edge)
+                                      iBase.Type.edge)
         self.assert_((coords == result).all())
         coords = self.geom.getEntEval(edges, [[0,1,0],[0,-1,0]],
-                                      Stg.interleaved, iBase.Type.edge)
+                                      iBase.Type.edge)
         self.assert_((coords == result).all())
 
         ##### faces; 1 entity, 1 vertex
@@ -380,12 +348,11 @@ class TestDiff(unittest.TestCase):
                                [ 1,  0,  0,] ])
         coords = self.geom.getEntEval(faces[0], [0,1,0])
         self.assert_((coords == result).all())
-        coords = self.geom.getEntEval(faces[0:1], [0,1,0], Stg.interleaved)
+        coords = self.geom.getEntEval(faces[0:1], [0,1,0])
         self.assert_((coords == result.reshape(4,1,3)).all())
-        coords = self.geom.getEntEval(faces[0], [0,1,0], type=iBase.Type.face)
+        coords = self.geom.getEntEval(faces[0], [0,1,0], iBase.Type.face)
         self.assert_((coords == result).all())
-        coords = self.geom.getEntEval(faces[0:1], [0,1,0], Stg.interleaved,
-                                      iBase.Type.face)
+        coords = self.geom.getEntEval(faces[0:1], [0,1,0], iBase.Type.face)
         self.assert_((coords == result.reshape(4,1,3)).all())
 
         ##### faces; 1 entity, n vertices
@@ -394,11 +361,10 @@ class TestDiff(unittest.TestCase):
                                [[ 0,  0,  0,], [ 0,  0,  0,]],
                                [[ 1,  0,  0,], [-1,  0,  0,]] ])
 
-        coords = self.geom.getEntEval(faces[0], [[0,1,0],[0,-1,0]],
-                                      Stg.interleaved)
+        coords = self.geom.getEntEval(faces[0], [[0,1,0],[0,-1,0]])
         self.assert_((coords == result).all())
         coords = self.geom.getEntEval(faces[0], [[0,1,0],[0,-1,0]],
-                                      Stg.interleaved, iBase.Type.face)
+                                      iBase.Type.face)
         self.assert_((coords == result).all())
 
         ##### faces; n entities, 1 vertex
@@ -406,10 +372,9 @@ class TestDiff(unittest.TestCase):
                                [[ 0,  1,  0,], [ 0,  0, -1,], [ 0,  0,  1,]],
                                [[ 0,  0,  0,], [-0,  0,  0,], [ 0,  0,  0,]],
                                [[ 1,  0,  0,], [ 0,  0,  0,], [ 0,  0,  0,]] ])
-        coords = self.geom.getEntEval(faces, [0,1,0], Stg.interleaved)
+        coords = self.geom.getEntEval(faces, [0,1,0])
         self.assert_((coords == result).all())
-        coords = self.geom.getEntEval(faces, [0,1,0], Stg.interleaved,
-                                      iBase.Type.face)
+        coords = self.geom.getEntEval(faces, [0,1,0], iBase.Type.face)
         self.assert_((coords == result).all())
 
         ##### faces; n entities, n vertices
@@ -417,10 +382,9 @@ class TestDiff(unittest.TestCase):
                                [[ 0,  1,  0,], [ 0,  0, -1,], [ 0,  0,  1,]],
                                [[ 0,  0,  0,], [-0,  0,  0,], [ 0,  0,  0,]],
                                [[ 1,  0,  0,], [ 0,  0,  0,], [ 0,  0,  0,]] ])
-        coords = self.geom.getEntEval(faces, [[0,1,0]]*3, Stg.interleaved)
+        coords = self.geom.getEntEval(faces, [[0,1,0]]*3)
         self.assert_((coords == result).all())
-        coords = self.geom.getEntEval(faces, [[0,1,0]]*3, Stg.interleaved,
-                                      iBase.Type.face)
+        coords = self.geom.getEntEval(faces, [[0,1,0]]*3, iBase.Type.face)
         self.assert_((coords == result).all())
 
     def testClassification(self):
@@ -431,13 +395,12 @@ class TestDiff(unittest.TestCase):
         self.assert_(found in faces)
         self.assertRaises(iBase.ITAPSError, self.geom.getPtClass, [2, 2, 4])
 
-        found = self.geom.getPtClass([[1, 1, 2], [1, 2, 1], [2, 1, 1]],
-                                     Stg.interleaved)
+        found = self.geom.getPtClass([[1, 1, 2], [1, 2, 1], [2, 1, 1]])
         for i in found:
             self.assert_(i in faces)
         
         self.assertRaises(iBase.ITAPSError, self.geom.getPtClass,
-                          [[2, 2, 4], [1, 2, 1], [2, 1, 1]], Stg.interleaved)
+                          [[2, 2, 4], [1, 2, 1], [2, 1, 1]])
 
     def testNormalSense(self):
         self.geom.createBrick(2, 2, 2)
@@ -545,7 +508,7 @@ class TestDiff(unittest.TestCase):
 
         # TODO: this always causes a floating point exception for some reason
         self.fail("getPtRayIntersect will crash, ignoring it")
-        print self.geom.getPtRayIntersect([5,0,0], [1,0,0], Stg.blocked)
+        # print self.geom.getPtRayIntersect([5,0,0], [1,0,0])
 
     def test1stDeriv(self):
         self.geom.createBrick(1, 1, 1)
@@ -569,16 +532,15 @@ class TestDiff(unittest.TestCase):
         self.assert_((deriv[0] == u[0]).all())
         self.assert_((deriv[1] == v[0]).all())
 
-        deriv = self.geom.getEnt1stDerivative(faces[0:1], [[0,0]],
-                                              Stg.interleaved)
+        deriv = self.geom.getEnt1stDerivative(faces[0:1], [[0,0]])
         self.assert_((deriv.offsets == offsets[0:2]).all())
-        self.assert_((deriv.raw[0] == u[0:1]).all())
-        self.assert_((deriv.raw[1] == v[0:1]).all())
+        self.assert_((deriv.data[0] == u[0:1]).all())
+        self.assert_((deriv.data[1] == v[0:1]).all())
 
-        deriv = self.geom.getEnt1stDerivative(faces, [[0,0]]*6, Stg.interleaved)
+        deriv = self.geom.getEnt1stDerivative(faces, [[0,0]]*6)
         self.assert_((deriv.offsets == offsets).all())
-        self.assert_((deriv.raw[0] == u).all())
-        self.assert_((deriv.raw[1] == v).all())
+        self.assert_((deriv.data[0] == u).all())
+        self.assert_((deriv.data[1] == v).all())
 
     def test2ndDeriv(self):
         self.geom.createBrick(1, 1, 1)
@@ -590,7 +552,7 @@ class TestDiff(unittest.TestCase):
         deriv = self.geom.getEnt2ndDerivative(faces[0:1], [[0,0]],
                                               Stg.interleaved)
 
-        deriv = self.geom.getEnt2ndDerivative(faces, [[0,0]]*6, Stg.interleaved)
+        deriv = self.geom.getEnt2ndDerivative(faces, [[0,0]]*6)
 
 
 if __name__ == '__main__':
