@@ -31,16 +31,19 @@ class TestEntSet(unittest.TestCase):
         self.assertFalse(self.set.contains(ent))
         self.assert_(ent not in self.set)
         self.assertEqual(self.set.getNumOfType(iBase.Type.all), 0)
+        self.assertEqual(len(self.set), 0)
 
         self.set.add(ent)
         self.assert_(self.set.contains(ent))
         self.assert_(ent in self.set)
         self.assertEqual(self.set.getNumOfType(iBase.Type.all), 1)
+        self.assertEqual(len(self.set), 1)
 
         self.set.remove(ent)
         self.assertFalse(self.set.contains(ent))
         self.assert_(ent not in self.set)
         self.assertEqual(self.set.getNumOfType(iBase.Type.all), 0)
+        self.assertEqual(len(self.set), 0)
 
     def testEntArr(self):
         self.geom.createBrick(1,1,1)
@@ -49,16 +52,19 @@ class TestEntSet(unittest.TestCase):
         self.assertFalse(self.set.contains(ents).any())
         self.assertEqual(self.set.getNumOfType(iBase.Type.all), 0)
         self.assertEqual(len(self.set.getEntities(iBase.Type.all)), 0)
+        self.assertEqual(len(self.set), 0)
 
         self.set.add(ents)
         self.assert_(self.set.contains(ents).all())
         self.assertEqual(self.set.getNumOfType(iBase.Type.all), 1+6+12+8)
         self.assertEqual(len(self.set.getEntities(iBase.Type.all)), 1+6+12+8)
+        self.assertEqual(len(self.set), 1+6+12+8)
 
         self.set.remove(ents)
         self.assertFalse(self.set.contains(ents).any())
         self.assertEqual(self.set.getNumOfType(iBase.Type.all), 0)
         self.assertEqual(len(self.set.getEntities(iBase.Type.all)), 0)
+        self.assertEqual(len(self.set), 0)
 
     def testEntSet(self):
         sub = self.geom.createEntSet(True)
