@@ -95,9 +95,8 @@ class TestTags(unittest.TestCase):
         self.dtag.setData(self.ent, 42)
 
         tags = self.geom.getAllTags(self.ent)
-        self.assertEqual(tags[0].name, self.itag.name) # TODO: ignore order?
-        self.assertEqual(tags[1].name, self.dtag.name)
-
+        self.assert_(self.itag in tags)
+        self.assert_(self.dtag in tags)
 
     def testIntArrData(self):
         self.itag.setData(self.ents, 3*[42])
@@ -188,8 +187,8 @@ class TestTags(unittest.TestCase):
         self.dtag.setData(self.set, 42)
 
         tags = self.geom.getAllTags(self.set)
-        self.assertEqual(tags[0].name, self.itag.name) # TODO: ignore order?
-        self.assertEqual(tags[1].name, self.dtag.name)
+        self.assert_(self.itag in tags)
+        self.assert_(self.dtag in tags)
 
 
 if __name__ == '__main__':
